﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Schedules;

namespace ScheduleSample
{
    public class ScheduleData
    {
        private ObservableCollection<Resource> _resources = new ObservableCollection<Resource>();
        private ObservableCollection<ResourceCalendar> _resourceCalendars = new ObservableCollection<ResourceCalendar>();
        private ObservableCollection<Appointment> _appointments = new ObservableCollection<Appointment>();

        public ObservableCollection<Resource> Resources
        {
            get { return _resources; }
            set { _resources = value; }
        }

        public ObservableCollection<ResourceCalendar> ResourceCalendars
        {
            get { return _resourceCalendars; }
            set { _resourceCalendars = value; }
        }

        public ObservableCollection<Appointment> Appointments
        {
            get { return _appointments; }
            set { _appointments = value; }
        }

        public ScheduleData()
        {
            InitializeData();
        }

        private void InitializeData()
        {
            #region Initialize users

            Resource user1 = new Resource { Name = "User 1", Id = "user1" };
            Resource user2 = new Resource { Name = "User 2", Id = "user2" };
            this.Resources.Add(user1);
            this.Resources.Add(user2);

            #endregion // Initialize users

            #region Initialize calendars

            ResourceCalendar user1Calendar1 = new ResourceCalendar { Name = "User1 Calendar1", OwningResourceId = "user1", Id = "user1Calendar1" };
            ResourceCalendar user1Calendar2 = new ResourceCalendar { Name = "User1 Calendar2", OwningResourceId = "user1", Id = "user1Calendar2" };
            ResourceCalendar user2Calendar1 = new ResourceCalendar { Name = "User2 Calendar1", OwningResourceId = "user2", Id = "user2Calendar1" };
            this.ResourceCalendars.Add(user1Calendar1);
            this.ResourceCalendars.Add(user1Calendar2);
            this.ResourceCalendars.Add(user2Calendar1);

            #endregion //Initialize calendars

            #region InitializeAppointments

            Appointment user1Appointment1 = new Appointment { Id = "user1Appointment1", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Appointment1.Subject = "User1 First Appointment";
            user1Appointment1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user1Appointment1.End = new DateTime(DateTime.Now.AddDays(3).Year, DateTime.Now.AddDays(3).Month, DateTime.Now.AddDays(3).Day, 11, 0, 0);

            Appointment user1Appointment2 = new Appointment { Id = "user1Appointment2", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Appointment2.Subject = "User1 Second Appointment";
            user1Appointment2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment2.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment3 = new Appointment { Id = "user1Appointment3", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Appointment3.Subject = "User1 Third Appointment";
            user1Appointment3.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment3.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment4 = new Appointment { Id = "user1Appointment4", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment4.Subject = "User1 Fourth Appointment";
            user1Appointment4.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment4.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment5 = new Appointment { Id = "user1Appointment5", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment5.Subject = "User1 Fifth Appointment";
            user1Appointment5.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment5.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment6 = new Appointment { Id = "user1Appointment6", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment6.Subject = "User1 Sixth Appointment";
            user1Appointment6.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user1Appointment6.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);

            Appointment user2Appointment1 = new Appointment { Id = "user2Appointment1", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2Appointment1.Subject = "User2 First Appointment";
            user2Appointment1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user2Appointment1.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);

            Appointment user2Appointment2 = new Appointment { Id = "user2Appointment2", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2Appointment2.Subject = "User2 Second Appointment";
            user2Appointment2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user2Appointment2.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            this.Appointments.Add(user1Appointment1);
            this.Appointments.Add(user1Appointment2);
            this.Appointments.Add(user1Appointment3);
            this.Appointments.Add(user1Appointment4);
            this.Appointments.Add(user1Appointment5);
            this.Appointments.Add(user1Appointment6);
            this.Appointments.Add(user2Appointment1);
            this.Appointments.Add(user2Appointment2);

            #endregion //InitializeAppointments
        }
    }
}
